package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysMilestone;

public interface SysMilestoneMapper
{
    public SysMilestone selectSysMilestoneById(Long id);

    public List<SysMilestone> selectSysMilestoneList(SysMilestone sysMilestone);

    public int insertSysMilestone(SysMilestone sysMilestone);

    public int updateSysMilestone(SysMilestone sysMilestone);

    public int deleteSysMilestoneById(Long id);

    public int deleteSysMilestoneByIds(Long[] ids);
}
